﻿namespace UltraGridSummariesAndTotals
{
    using System.Drawing;

    using Infragistics.Win;
    using Infragistics.Win.UltraWinGrid;

    public class MyCreationFilter : IUIElementCreationFilter
    {
        private int summaryValueUIElementHeight = -1;

        public void AfterCreateChildElements(UIElement parent)
        {
            FixedSummaryLineUIElement fixedSummaryLineUIElement = parent as FixedSummaryLineUIElement;
            if (fixedSummaryLineUIElement != null)
            {
                RowsCollection grandTotalRows = fixedSummaryLineUIElement.Parent.Parent.GetContext(typeof(RowsCollection)) as RowsCollection;
                if (grandTotalRows.SummaryValues.SummaryFooterCaptionResolved == "Grand Summaries")
                {
                    int summaryCellsCount = fixedSummaryLineUIElement.ChildElements.Count;
                    if (this.summaryValueUIElementHeight < 0)
                    {
                        this.summaryValueUIElementHeight = fixedSummaryLineUIElement.Rect.Height;
                    }

                    SummaryFooterUIElement summaryFooterUIElement = fixedSummaryLineUIElement.Parent.Parent as SummaryFooterUIElement;
                    summaryFooterUIElement.Rect = new Rectangle(
                                                                summaryFooterUIElement.Rect.X,
                                                                summaryFooterUIElement.Rect.Y,
                                                                summaryFooterUIElement.Rect.Width,
                                                                this.summaryValueUIElementHeight * (summaryCellsCount + 1));

                    FixedSummaryAreaUIElement fixedSummaryAreaUIElement = fixedSummaryLineUIElement.Parent as FixedSummaryAreaUIElement;
                    fixedSummaryAreaUIElement.Rect = new Rectangle(
                                                                   fixedSummaryAreaUIElement.Rect.X,
                                                                   fixedSummaryAreaUIElement.Rect.Y,
                                                                   fixedSummaryAreaUIElement.Rect.Width,
                                                                   this.summaryValueUIElementHeight * summaryCellsCount);

                    fixedSummaryLineUIElement.Rect = new Rectangle(
                                                                    fixedSummaryLineUIElement.Rect.X,
                                                                    fixedSummaryLineUIElement.Rect.Y,
                                                                    fixedSummaryLineUIElement.Rect.Width,
                                                                    this.summaryValueUIElementHeight * summaryCellsCount);

                    SummaryValueUIElement summaryValueUIElementBase = fixedSummaryLineUIElement.ChildElements[summaryCellsCount - 1] as SummaryValueUIElement;
                    int baseX = fixedSummaryLineUIElement.Rect.Right - summaryValueUIElementBase.Rect.Width;
                    int baseY = fixedSummaryLineUIElement.Rect.Y;

                    for (int child = summaryCellsCount - 1; child >= 0; child--)
                    {
                        int transition = summaryCellsCount - child - 1;

                        SummaryValueUIElement summaryValueUIElement = fixedSummaryLineUIElement.ChildElements[child] as SummaryValueUIElement;
                        summaryValueUIElement.Rect = new Rectangle(
                                                                baseX,
                                                                baseY + this.summaryValueUIElementHeight * transition,
                                                                summaryValueUIElement.Rect.Width,
                                                                this.summaryValueUIElementHeight);
                    }
                }
            }
        }

        public bool BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }
    }
}